==> h4_100.tgz: hos-v4/include/knl_exc.h <==
/* ------------------------------------------------------------------------ */
/*  Hyper Operating System V4  ITRON4.0 Real-Time OS                  */
/*    ͥ¸إå CPU㳰ϥɥ                        */
/*                                                                          */
/*                                  Copyright (C) 1998-2002 by Project HOS  */
/*                                  http://sourceforge.jp/projects/hos/     */
/* ------------------------------------------------------------------------ */


#ifndef __HOS_V4__knl_exc_h__
#define __HOS_V4__knl_exc_h__


#include "knl_hos.h"



/* ------------------------------------------ */
/*                                    */
/* ------------------------------------------ */

/* ֹϰ */
#define KERNEL_TMIN_EXCNO	(kernel_min_excno)	/* CPU㳰ϥɥֹκǾ */
#define KERNEL_TMAX_EXCNO	(KERNEL_TMIN_EXCNO + kernel_exccb_cnt - 1)
												/* CPU㳰ϥɥֹκ */



/* ------------------------------------------ */
/*                                      */
/* ------------------------------------------ */

/* CPU㳰ϥɥ饳ȥ֥å */
typedef struct t_kernel_exccb
{
	FP exchdr;			/* CPU㳰ϥɥεư */
} T_KERNEL_EXCCB;



/* ---------------------------------- */
/*        Хѿ          */
/* ---------------------------------- */

/*  CPU㳰ϥɥ */
extern T_KERNEL_EXCCB  kernel_exccb_tbl[];	/* CPU㳰ϥɥ饳ȥ֥åơ֥ */
extern const INT       kernel_exccb_cnt;	/* CPU㳰ϥɥֹ */
extern const EXCNO     kernel_min_excno;	/* CPU㳰ϥɥֹǾ */



/* ------------------------------------------ */
/*                ؿ                    */
/* ------------------------------------------ */

#ifdef __cplusplus
extern "C" {
#endif

/* CPU㳰ϥɥ */
void    kernel_sta_exc(void);			/* CPU㳰ϥɥγ */
void    kernel_end_exc(void);			/* CPU㳰ϥɥνλ */
void    kernel_exe_exc(INTNO excno);	/* CPU㳰ϥɥ¹ */

#ifdef __cplusplus
}
#endif



#endif	/*  __HOS_V4__knl_exc_h__ */


/* ------------------------------------------------------------------------ */
/*  Copyright (C) 1998-2002 by Project HOS                                  */
/* ------------------------------------------------------------------------ */

==> h4_101.tgz: hos-v4/include/knl_exc.h <==
/* ------------------------------------------------------------------------ */
/*  Hyper Operating System V4  ITRON4.0 Real-Time OS                  */
/*    ͥ¸إå CPU㳰ϥɥ                        */
/*                                                                          */
/*                                  Copyright (C) 1998-2002 by Project HOS  */
/*                                  http://sourceforge.jp/projects/hos/     */
/* ------------------------------------------------------------------------ */


#ifndef __HOS_V4__knl_exc_h__
#define __HOS_V4__knl_exc_h__


#include "knl_hos.h"

/* ------------------------------------------ */
/*                                    */
/* ------------------------------------------ */

/* ֹϰ */
#define KERNEL_TMIN_EXCNO	(kernel_min_excno)	/* CPU㳰ϥɥֹκǾ */
#define KERNEL_TMAX_EXCNO	(KERNEL_TMIN_EXCNO + kernel_exccb_cnt - 1)
												/* CPU㳰ϥɥֹκ */



/* ------------------------------------------ */
/*                                      */
/* ------------------------------------------ */

/* CPU㳰ϥɥ饳ȥ֥å */
typedef struct t_kernel_exccb
{
	FP exchdr;			/* CPU㳰ϥɥεư */
} T_KERNEL_EXCCB;



/* ---------------------------------- */
/*        Хѿ          */
/* ---------------------------------- */

/*  CPU㳰ϥɥ */
extern T_KERNEL_EXCCB  kernel_exccb_tbl[];	/* CPU㳰ϥɥ饳ȥ֥åơ֥ */
extern const INT       kernel_exccb_cnt;	/* CPU㳰ϥɥֹ */
extern const EXCNO     kernel_min_excno;	/* CPU㳰ϥɥֹǾ */



/* ------------------------------------------ */
/*                ؿ                    */
/* ------------------------------------------ */

#ifdef __cplusplus
extern "C" {
#endif

/* CPU㳰ϥɥ */
void    kernel_sta_exc(void);			/* CPU㳰ϥɥγ */
void    kernel_end_exc(void);			/* CPU㳰ϥɥνλ */
void    kernel_exe_exc(EXCNO excno);	/* CPU㳰ϥɥ¹ */

#ifdef __cplusplus
}
#endif



#endif	/*  __HOS_V4__knl_exc_h__ */


/* ------------------------------------------------------------------------ */
/*  Copyright (C) 1998-2002 by Project HOS                                  */
/* ------------------------------------------------------------------------ */
